@@ -8,10 +8,13 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.1.9'
+__version__ = '0.2'
 
 
-def format_code(source, summary_wrap_length=0):
+def format_code(source,
+                summary_wrap_length=0,
+                pre_summary_newline=False,
+                post_description_blank=True):
     """Return source code with docstrings formatted.
 
     Wrap summary lines if summary_wrap_length is greater than 0.
@@ -50,7 +53,9 @@ def format_code(source, summary_wrap_length=0):
             formatted += format_docstring(
                 previous_token_string,
                 token_string,
-                summary_wrap_length=summary_wrap_length)
+                summary_wrap_length=summary_wrap_length,
+                pre_summary_newline=pre_summary_newline,
+                post_description_blank=post_description_blank)
         else:
             formatted += token_string
 
@@ -70,7 +75,10 @@ def starts_with_triple(string):
             string.strip().startswith("'''"))
 
 
-def format_docstring(indentation, docstring, summary_wrap_length=0):
+def format_docstring(indentation, docstring,
+                     summary_wrap_length=0,
+                     pre_summary_newline=False,
+                     post_description_blank=True):
     """Return formatted version of docstring.
 
     Wrap summary lines if summary_wrap_length is greater than 0.
@@ -95,15 +103,25 @@ def format_docstring(indentation, docstring, summary_wrap_length=0):
     summary, description = split_summary_and_description(contents)
 
     if description:
+        if pre_summary_newline:
+            summary = indentation + summary
+        else:
+            # Compensate for triple quotes by temporarily prepending 3 spaces.
+            # This temporary prepending is undone below.
+            summary = 3 * ' ' + summary
+
         return '''\
-"""{summary}
-
-{description}
+"""{pre_summary}{summary}
 
+{description}{post_description}
 {indentation}"""\
-'''.format(summary=normalize_summary(summary, summary_wrap_length),
+'''.format(pre_summary=('\n' + indentation if pre_summary_newline else ''),
+           summary=normalize_summary(summary,
+                                     summary_wrap_length,
+                                     indentation).lstrip(),
            description='\n'.join([indent_non_indented(l, indentation).rstrip()
                                   for l in description.splitlines()]),
+           post_description=('\n' if post_description_blank else ''),
            indentation=indentation)
     else:
         return '"""' + normalize_summary(contents, summary_wrap_length) + '"""'
@@ -149,10 +167,10 @@ def strip_docstring(docstring):
     return docstring.split(triple, 1)[1].rsplit(triple, 1)[0].strip()
 
 
-def normalize_summary(summary, wrap_length=0):
+def normalize_summary(summary, wrap_length=0, indentation=''):
     """Return normalized docstring summary."""
     # Remove newlines
-    summary = re.sub('\s*\n\s*', ' ', summary.strip())
+    summary = re.sub('\s*\n\s*', ' ', summary.rstrip())
 
     # Add period at end of sentence
     if summary and summary[-1].isalnum():
@@ -161,9 +179,10 @@ def normalize_summary(summary, wrap_length=0):
     # This is disabled by default since it goes against PEP 257
     if wrap_length > 0:
         import textwrap
-        # Compensate for triple quotes by temporarily prepending 3 spaces
-        summary = '\n'.join(textwrap.wrap(' ' * 3 + summary,
-                                          width=wrap_length)).strip()
+        summary = '\n'.join(
+            textwrap.wrap(summary,
+                          width=wrap_length,
+                          subsequent_indent=indentation)).strip()
 
     return summary
 
@@ -181,13 +200,16 @@ def detect_encoding(filename):
     """Return file encoding."""
     try:
         # Python 3
-        with open(filename, 'rb') as input_file:
-            encoding = tokenize.detect_encoding(input_file.readline)[0]
         try:
+            with open(filename, 'rb') as input_file:
+                encoding = tokenize.detect_encoding(input_file.readline)[0]
+
+            # Check for correctness of encoding
             with open(filename, encoding=encoding) as input_file:
                 input_file.read()
+
             return encoding
-        except UnicodeDecodeError:
+        except (SyntaxError, LookupError, UnicodeDecodeError):
             return 'latin-1'
     except AttributeError:
         return 'utf-8'
@@ -204,19 +226,37 @@ def main(argv, standard_out):
     parser.add_argument(
         '--wrap-long-summaries', default=0, type=int, metavar='LENGTH',
         help='wrap long summary lines at this length (default: %(default)s)')
+    parser.add_argument('--no-blank', dest='post_description_blank',
+                        action='store_false',
+                        help='do not add blank line after description')
+    parser.add_argument('--pre-summary-newline',
+                        action='store_true',
+                        help='add a newline before the summary of a '
+                             'multi-line docstring')
+    parser.add_argument('--alternate-style',
+                        action='store_true',
+                        help='enables --no-blank, --pre-summary-newline, and '
+                             '--wrap-long-summaries=79')
     parser.add_argument('--version', action='version', version=__version__)
     parser.add_argument('files', nargs='+',
                         help='files to format')
 
     args = parser.parse_args(argv[1:])
 
+    if args.alternate_style:
+        args.pre_summary_newline = True
+        args.post_description_blank = False
+        args.wrap_long_summaries = 79
+
     for filename in args.files:
         encoding = detect_encoding(filename)
         with open_with_encoding(filename, encoding=encoding) as input_file:
             source = input_file.read()
             formatted_source = format_code(
                 source,
-                summary_wrap_length=args.wrap_long_summaries)
+                summary_wrap_length=args.wrap_long_summaries,
+                pre_summary_newline=args.pre_summary_newline,
+                post_description_blank=args.post_description_blank)
 
         if source != formatted_source:
             if args.in_place:
